@@ -127,13 +127,17 @@ class ItemMetadata(models.Model):
 
     item = models.OneToOneField('Item', related_name='metadatas', on_delete=models.PROTECT)
 
-    natural_key = models.CharField(max_length=1024, default="")
+    natural_key = models.CharField(max_length=1024, default="", unique=True)
 
     """
     JSON field integration
     """
     metadata = models.TextField(default="", null=False)
 
+    @staticmethod
+    def get_natural_key(collection, raw_natural_key):
+        return '%s|%s' % (collection.name, raw_natural_key)
+
     def __init__(self, *args, **kwargs):
         self.__metadata_obj = None
         self.__raw_natural_key = None
@@ -965,6 +969,9 @@ class MetaCategory(models.Model):
         (DISAGREEMENT, 'disagreement'),
     )
 
+    class Meta:
+        unique_together = (("collection", "label"),)
+
     collection = models.ForeignKey(Collection, related_name="metacategories", on_delete=models.PROTECT)
     label = models.CharField(max_length=255)
     triggers_notifications = models.IntegerField(
